Home
last modified time | relevance | path

Searched refs:__constant__ (Results 1 – 25 of 38) sorted by relevance

12

/llvm-project-15.0.7/clang/test/SemaCUDA/
H A Ddevice-var-init.cu28 __constant__ T c_t_i = {2};
38 __constant__ EC c_ec_i(3);
66 __constant__ UC c_uc;
73 __constant__ UD c_ud;
80 __constant__ ECI c_eci;
87 __constant__ NEC c_nec;
94 __constant__ NED c_ned;
101 __constant__ NCV c_ncv;
108 __constant__ VD c_vd;
115 __constant__ NCF c_ncf;
[all …]
H A Dbad-attributes.cu18 __constant__ int c1;
19 __constant__ void c2(); // expected-warning {{attribute only applies to variables}}
29 __device__ __constant__ int z2;
38 __constant__ __device__ int z7;
39 __constant__ __shared__ int z8; // expected-error {{attributes are not compatible}}
43 __shared__ __constant__ int z10; // expected-error {{attributes are not compatible}}
45 __constant__ __shared__ int z10a; // expected-error {{attributes are not compatible}}
65 __constant__ int global_constant;
67__constant__ int c; // expected-error {{__constant__, __device__, and __managed__ are not allowed … in host_fn()
71__constant__ int c; // expected-error {{__constant__, __device__, and __managed__ are not allowed … in device_fn()
H A Dmanaged-var.cu20 __managed__ __constant__ int m4;
24 __constant__ __managed__ int m4a;
H A Dattr-declspec.cu26 __declspec(__constant__) int* g_constant;
H A Dstatic-device-var.cu33 static __constant__ int y;
H A Dconstexpr-variables.cu80 __constant__ const bool &x = C<B>::value;
/llvm-project-15.0.7/clang/test/CodeGenCUDA/
H A Ddevice-var-init.cu28 __constant__ int c_v;
53 __constant__ T c_t;
60 __constant__ T c_t_i = {2};
71 __constant__ EC c_ec;
82 __constant__ ED c_ed;
92 __constant__ ECD c_ecd;
103 __constant__ ETC c_etc;
110 __constant__ NCFS c_ncfs;
121 __constant__ T_B_T c_t_b_t;
132 __constant__ T_F_T c_t_f_t;
[all …]
H A Dconstexpr-variables.cu10 __constant__ const int &use_a = a;
16 __constant__ const int &use_B_b = B::b;
28 __constant__ const int &use_Q_k1 = Q::k1;
29 __constant__ const int &use_Q_k2 = Q::k2;
36 __constant__ const int &use_X_a = X<int>::a;
43 __constant__ const int &y = A<int, 1, 2>::x;
H A Ddevice-var-linkage.cu26 __constant__ int v2;
39 extern __constant__ int ev2;
55 static __constant__ int sv2;
H A Ddevice-stub.cu77 __constant__ int constant_var;
99 extern __constant__ int ext_constant_var;
111 __constant__ int ext_constant_var_def = 2;
H A Dhost-used-device-var.cu22 __constant__ int v2;
35 __constant__ int u2;
80 __constant__ constexpr int constexpr_var2a = 2;
81 inline __constant__ constexpr int constexpr_var2b = 2;
H A Dunused-global-var.cu22 __constant__ int v2;
39 __constant__ int u2;
H A Dstatic-device-var-no-rdc.cu57 static __constant__ int y;
95 const static __constant__ int local_static_constant = 42; in kernel()
H A Damdgpu-visibility.cu13 __constant__ int c;
H A Ddebug-info-address-class.cu13 __device__ __constant__ int FileVar2;
H A Dfilter-decl.cu14 __constant__ char constantdata[256];
H A Dstatic-device-var-rdc.cu91 static __constant__ int y;
H A Daddress-spaces.cu13 __constant__ int j;
/llvm-project-15.0.7/clang/test/AST/
H A Dast-dump-constant-var.cu8 __constant__ int m1;
13 __constant__ __constant__ int m2;
26 constexpr __constant__ int m3a = 2;
32 __constant__ constexpr int m3b = 3;
/llvm-project-15.0.7/clang/test/CodeGenHIP/
H A Dhipspv-addr-spaces.cpp6 #define __constant__ __attribute__((constant)) macro
14 __constant__ int c;
/llvm-project-15.0.7/clang/test/CodeGenCUDA/Inputs/
H A Dcuda.h6 #define __constant__ __attribute__((constant)) macro
16 #define __constant__ macro
/llvm-project-15.0.7/clang/test/CodeGen/
H A Dbuiltins-nvptx-ptx50.cu11 #define __constant__ __attribute__((constant)) macro
H A Dbuiltins-nvptx-ptx60.cu19 #define __constant__ __attribute__((constant)) macro
/llvm-project-15.0.7/clang/test/PCH/Inputs/
H A Dcuda.h5 #define __constant__ __attribute__((constant)) macro
/llvm-project-15.0.7/clang/lib/Headers/openmp_wrappers/
H A Dcmath81 #pragma push_macro("__constant__")
82 #define __constant__ __attribute__((constant))
87 #pragma pop_macro("__constant__")

12